#[repr(u32)]pub enum GuestType {
Zircon = 0,
Debian = 1,
Termina = 2,
}Expand description
The available guest types.
Variants
Zircon = 0
A minimal Fuchsia system that boots to a Zircon virtcon.
Debian = 1
A Debian guest, exact version dependent on prebuilts.
Termina = 2
A Linux guest that contains additional features for Vulkan and window manager integration, based on the Termina VM from ChromeOS.
Implementations
Sourceimpl GuestType
impl GuestType
pub fn from_primitive(prim: u32) -> Option<Self>
pub const fn into_primitive(self) -> u32